@@ -42,6 +42,7 @@ Solvers
 .. autofunction:: cho_solve
 .. autofunction:: lu_solve
 .. autofunction:: solve
+.. autofunction:: hsolve
 .. autofunction:: rsolve
 .. autofunction:: stl
 .. autofunction:: lstsq
@@ -57,7 +58,7 @@ from .lu import lu_slogdet, lu_solve
 from .property import check_semidefinite_positiveness
 from .property import check_definite_positiveness, check_symmetry
 from .qs import economic_qs, economic_qs_linear
-from .solve import rsolve, solve
+from .solve import rsolve, solve, hsolve
 from .svd import economic_svd
 from .tri import stl
 
@@ -65,5 +66,5 @@ __all__ = [
     'cho_solve', 'sum2diag', 'trace2', 'ddot', 'dotd', 'lu_slogdet',
     'lu_solve', 'check_definite_positiveness', 'check_symmetry', 'economic_qs',
     'economic_qs_linear', 'solve', 'rsolve', 'economic_svd', 'stl', 'lstsq',
-    'plogdet', 'check_semidefinite_positiveness', 'cdot'
+    'plogdet', 'check_semidefinite_positiveness', 'cdot', 'hsolve'
 ]
